# == Class: proxmox::params
#
class proxmox::params {
  case $::osfamily {
    'Debian': {
      if $::operatingsystem == 'Debian' and versioncmp($::operatingsystemrelease, '7.0') >= 0 {
        # Virtual Environment packages
        $ve_pkg_ensure              = 'present'
        $ve_pkg_name                = [ 'proxmox-ve-2.6.32', 'ksm-control-daemon', 'vzprocps', 'open-iscsi', 'bootlogd', 'pve-firmware' ]

        # PVE Kernel
        $kvm_only                   = false
        $kernel_kvm_pkg_name        = [ 'pve-kernel-3.10.0-5-pve' ]
        $kernel_pkg_name            = [ 'pve-kernel-2.6.32-34-pve' ]

        # Recommended packages
        $rec_pkg_name               = [ 'ntp', 'ssh', 'lvm2', 'bridge-utils' ]

        # Old useless packages
        $old_pkg_ensure             = 'absent'
        $old_pkg_name               = [ 'acpid',  'linux-image-amd64', 'linux-base', 'linux-image-3.2.0-4-amd64' ]

        # 
        $pve_enterprise_repo_ensure = 'absent'

        # Pveproxy access restriction
        $pveproxy_default_path      = '/etc/default/pveproxy'
        $pveproxy_default_content   = 'proxmox/hypervisor/pveproxy_default.erb'
        $pveproxy_allow             = '127.0.0.1'
        $pveproxy_deny              = 'all'
        $pveproxy_policy            = 'allow'
        $pveproxy_service_name      = 'pveproxy'
        $pveproxy_service_manage    = true 
        $pveproxy_service_enabled   = true
      }
    }
    default: {
      fail("Proxmox only works with Debian system; osfamily (${::osfamily}) or lsbdistid (${::lsbdistid}) is unsupported")
    }
  }


} # Private class: proxmox::params
